emayili package.This returns a function that can be used with the login_server(). Specifically,
the function takes two parameters, to_email and message.
emayili_emailer(
email_host = NULL,
email_port = NULL,
email_username = NULL,
email_password = NULL,
from_email = NULL
)returns a function to send an email using the emayili package.
SMTP email host.
SMPT email port.
username for the SMTP server.
password for the SMTP server.
the from email address sent from login_server().
login_server()